

UUID4_FLAG           = '__UUID4__'
CREATED_ON_FLAG      = '__CREATED-ON__'
UPDATED_ON_FLAG      = '__UPDATED-ON__'
SOFTWARE_REF_FLAG    = '__SOFTWARE__'
PARENT_REF_FLAG      = '__PARENT-REF__'
EXTERNAL_REF_FLAG    = '__EXTERNAL-REF__'
EXTERNAL_FILE_FLAG   = '__EXTERNAL-FILE__'
EXTERNAL_URL_FLAG    = '__EXTERNAL-URL__'
DEFINITION_TEXT_FLAG = '__DEF-TEXT__'
DEFINITION_URL_FLAG  = '__DEF-URL__'

HAS_HEADER_FLAG      = '__HAS-HEADER__'